@@ -1,5 +1,6 @@
+from dodo_commands import Dodo
 from dodo_commands.framework.args_tree import ArgsTreeNode
-from dodo_commands.framework import Dodo
+from dodo_commands.framework.decorator_utils import uses_decorator
 
 
 class Decorator:  # noqa
@@ -10,8 +11,11 @@ class Decorator:  # noqa
             default=False,
             help="Run the command through the debugger")
 
-    def modify_args(self, root_node, cwd):  # noqa
-        if not Dodo.args.use_debugger:
+    def is_used(self, config, command_name, decorator_name):
+        return uses_decorator(config, command_name, decorator_name)
+
+    def modify_args(self, command_line_args, root_node, cwd):  # noqa
+        if not getattr(command_line_args, 'use_debugger', False):
             return root_node, cwd
 
         debugger_node = ArgsTreeNode(
