@@ -1,7 +1,9 @@
-from argparse import ArgumentParser
-from dodo_commands.framework import Dodo, CommandError
 import os
-from dodo_commands.framework.config import load_global_config_parser, Paths
+from argparse import ArgumentParser
+
+from dodo_commands import CommandError, Dodo
+from dodo_commands.framework.global_config import load_global_config_parser
+from dodo_commands.framework.paths import Paths
 
 
 def _args():
@@ -10,7 +12,7 @@ def _args():
         "Show diff for a file in the Dodo Commands system directory.")
     parser.add_argument('file', nargs='?', help='Show diff for this file')
     parser.add_argument(
-        '--project-name', help='Compare to files from an alternative project')
+        '--env-name', help='Compare to files from an alternative environment')
     args = Dodo.parse_args(parser)
     return args
 
@@ -27,15 +29,14 @@ if Dodo.is_main(__name__):
     if not project_dir:
         raise CommandError("No active dodo commands project")
 
-    shared_config_dir = Dodo.get_config('/ROOT/shared_config_dir')
-
-    if args.project_name:
+    if args.env_name:
         ref_project_dir = os.path.abspath(
-            os.path.join(project_dir, "..", args.project_name))
+            os.path.join(project_dir, "..", args.env_name))
         original_file = os.path.join(ref_project_dir, file)
         copied_file = os.path.join(project_dir, file)
     else:
+        shared_config_dir = Dodo.get_config('/ROOT/shared_config_dir')
         original_file = os.path.realpath(os.path.join(shared_config_dir, file))
-        copied_file = os.path.join(Paths().res_dir(), file)
+        copied_file = os.path.join(Paths().config_dir(), file)
 
     Dodo.run([_diff_tool(), original_file, copied_file])
