@@ -1,5 +1,6 @@
 from argparse import ArgumentParser
-from dodo_commands.framework import Dodo
+
+from dodo_commands import Dodo
 from dodo_commands.framework.config import expand_keys
 
 
@@ -12,4 +13,4 @@ def _args():
 
 if Dodo.is_main(__name__):
     args = _args()
-    print(expand_keys(Dodo.config, args.text))
+    print(expand_keys(Dodo.get_config(), args.text))
