@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 """Utilities."""
-from six.moves import input as raw_input
 import os
 import sys
-import re
+import time
+
+from dodo_commands.dependencies.get import plumbum, six
+
+raw_input = six.moves.input
 
 
 def query_yes_no(question, default="yes"):
@@ -55,10 +58,7 @@ def remove_trailing_dashes(args):
 def bordered(text):
     lines = text.splitlines()
     width = max(len(s) for s in lines)
-    if is_windows():
-        tl, tr, bl, br, v, h = '+', '+', '+', '+', '|', '-'
-    else:
-        tl, tr, bl, br, v, h = '┌', '┐', '└', '┘', '│', '─'
+    tl, tr, bl, br, v, h = u'┌', u'┐', u'└', u'┘', u'│', u'─'
     res = [tl + h * width + tr]
     for s in lines:
         res.append(v + (s + ' ' * width)[:width] + v)
@@ -86,28 +86,9 @@ else:
         return textwrap.indent(text, amount * ch)
 
 
-def filter_choices(all_choices, raw_choice):
-    regexp = r"(\d)+(\-(\d)+)?,?"
-    result = []
-    span = [None, None]
-    for choice in [x for x in re.finditer(regexp, raw_choice)]:
-        if span[0] is None:
-            span[0] = choice.span()[0]
-        if span[1] is None or span[1] == choice.span()[0]:
-            span[1] = choice.span()[1]
-        from_index = int(choice.group(1)) - 1
-        if from_index < 0:
-            raise Exception("Invalid index")
-        to_index = int(choice.group(3)) - 1 if choice.group(3) else from_index
-        if to_index >= len(all_choices):
-            raise Exception("Invalid index")
-        for idx in range(from_index, to_index + 1):
-            result.append(all_choices[idx])
-    return result, span
-
-
-def is_windows():
-    return os.name == 'nt'
+def make_executable(script_filename):
+    st = os.stat(script_filename)
+    os.chmod(script_filename, st.st_mode | 0o111)
 
 
 def symlink(source, link_name):
@@ -129,3 +110,39 @@ def chop(path):
     while path and path[-1] in ('\n', '\r'):
         path = path[:-1]
     return path
+
+
+def _log(string):
+    with open('/tmp/.dodo.log', 'w') as ofs:
+        ofs.write(string + '\n')
+
+
+class EnvironMemo:
+    def __init__(self, extra_vars):
+        self.extra_vars = extra_vars
+        self.memo = {}
+
+    def __enter__(self):  # noqa
+        self.memo = os.environ.copy()
+        os.environ.update(self.extra_vars)
+
+    def __exit__(self, type, value, traceback):  # noqa
+        os.environ.clear()
+        os.environ.update(self.memo)
+
+
+def exe_exists(exe):
+    try:
+        plumbum.local[exe]
+        return True
+    except plumbum.commands.processes.CommandNotFound:
+        return False
+
+
+class classproperty(property):  # noqa
+    def __get__(self, cls, owner):  # noqa
+        return classmethod(self.fget).__get__(None, owner)()
+
+
+def maybe_list_to_list(maybe_list):
+    return (maybe_list if isinstance(maybe_list, list) else [maybe_list])
